@@ -8,8 +8,15 @@ class XpathParserTypeError(Exception):
         return repr("incorrect parser type")
 
 class ArgValueError(Exception):
-    def __init__(self, vaule):
-        self.vaule = vaule
+    def __init__(self, value):
+        self.value = value
+
+    def __str__(self):
+        return repr(self.value)
+
+class ParamsError(Exception):
+    def __init__(self, value):
+        self.value = value
 
     def __str__(self):
         return repr(self.value)
